// https://github.com/cmackay/google-analytics-plugin

var analytics = {
	defaultSettings: {enabled:true},

	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
		logger.info("ANALYTICS: initialize");
		var settings = analytics.getSettings();
		
		if(settings.enabled) {
		    // cmackay version
		    navigator.analytics.setTrackingId('UA-65840713-1');

			analytics.sendEvent("Analytics", "Enabled");
		
			// send analytics for first page as pagecontainershow event has already fired
			navigator.analytics.sendAppView($.mobile.activePage.attr('id'));
			
			// danwilson version
			//window.analytics.startTrackerWithId('UA-65840713-1')
			
			$(document).on( "pagecontainershow", function( event, ui ) {
				if(analytics.getSettings().enabled) {
					var pageId = $.mobile.activePage.attr('id');
					var pageTitle = document.title;
					logger.debug("ANALYTICS: page show: "+pageId+" "+pageTitle);

					// danwilson version
					//window.analytics.trackView(pageId);
					
					// cmackay version
					navigator.analytics.sendAppView(pageId, function() {
						logger.info("ANALYTICS: SUCCESS: id: '"+pageId+"' title: '"+pageTitle+"'");	
					}, function() {
						logger.error("ANALYTICS: ERROR: id: '"+pageId+"' title: '"+pageTitle+"'");	
					});
				}
			});
		} else {
			analytics.sendEvent("Analytics", "Disabled");
		}
		
		analytics.display();
		$("#toggle-analytics").change(analytics.toggleAnalytics);
	},
	display: function() {
		var settings = analytics.getSettings();
		var checked = settings.enabled ? "checked=''" : "";
		var html = "<form>";
		html += "<div class='ui-field-contain'>";
		html += "<label for='toggle-analytics'>Enable Analytics</label>";
		html += "<input type='checkbox' data-role='flipswitch' name='toggle-analytics' id='toggle-analytics' class='custom-size-flipswitch' "+checked+">";
		html += "</div>";
		html += "</form>";
		$("#analytics-settings").html(html);
	},
	sendEvent: function(category, action, label, value) {
		if (typeof(label)==='undefined') label = '';
		if (typeof(value)==='undefined') value = 0;
		
		if(analytics.getSettings().enabled) {
			navigator.analytics.sendEvent(category, action, label, value, function() {
				logger.info("ANALYTICS: EVENT: SUCCESS: category: '"+category+"' action: '"+action+"'");	
			}, function() {
				logger.error("ANALYTICS: EVENT: ERROR: category: '"+category+"' action: '"+action+"'");	
			});
		}
	},
	sendException: function(description, fatal) {
		if (typeof(fatal)==='undefined') fatal = false;

		logger.info("sendException: " + description);
		
		if (navigator.analytics && analytics.getSettings().enabled) {
			navigator.analytics.sendException(description, fatal, function() {
				logger.info("ANALYTICS: EXCEPTION: SUCCESS: description: '"+description+"' fatal: '"+fatal+"'");
			}, function() {});
		}
	},
	toggleAnalytics: function() {
		if(!$("#toggle-analytics").is(':checked')) {
			navigator.notification.confirm(
				'Are you sure you want to disable analytics? We collect anonymous usage data to allow us to develop a better app.',
				function(buttonIndex) {
					if(buttonIndex == 1) {
						analytics.sendEvent("Analytics", "Disable");
						var settings = analytics.getSettings();
						settings.enabled = $("#toggle-analytics").is(':checked');
						analytics.setSettings(settings);
						logger.info("ANALYTICS: ENABLED: "+settings.enabled);
					} else {
						$("#toggle-analytics")
							.off("change")
							.prop('checked', true)
							.flipswitch("refresh")
							.on("change", analytics.toggleAnalytics);
					}
				},            			
				'Disable Analytics?',           
				['Yes','No']  
			);
		} else {
			navigator.notification.confirm(
				'Are you sure you want to enable analytics? We collect anonymous usage data to allow us to develop a better app.',
				function(buttonIndex) {
					if(buttonIndex == 1) {
					analytics.sendEvent("Analytics", "Enable");
						var settings = analytics.getSettings();
						settings.enabled = $("#toggle-analytics").is(':checked');
						analytics.setSettings(settings);
						logger.info("ANALYTICS: ENABLED: "+settings.enabled);
					} else {
						$("#toggle-analytics")
							.off("change")
							.prop('checked', false)
							.flipswitch("refresh")
							.on("change", analytics.toggleAnalytics);
					}
				},            			
				'Enable Analytics?',           
				['Yes','No']  
			);
		}
	},
	getSettings: function() {
        // TODO: remove this
	    return analytics.defaultSettings;

		if(window.localStorage.getItem("analytics_settings") === null) {
			return analytics.defaultSettings;
		} else {
			return JSON.parse(window.localStorage.getItem("analytics_settings"));
		}
	},
	setSettings: function(settings) {
		window.localStorage.setItem("analytics_settings", JSON.stringify(settings));
	}
};