var feedback = {
	showFeedbackInterval:       7,
	showFeedbackIntervalUnit:   "days", 
	nextFeedbackInterval:       2,
	nextFeedbackIntervalUnit:   "months", 
	neverFeedbackInterval:      100,
	neverFeedbackIntervalUnit:  "years", 

	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
		feedback.display();
		$("#feedbacksavebutton").click(feedback.saveFeedback);
		$("#feedbacklaterbutton").click(feedback.dismissLaterFeedback);
		$("#feedbackneverbutton").click(feedback.dismissNeverFeedback);
		$('#feedback-thumbs-up').change(feedback.thumbsUp);
		$('#feedback-thumbs-down').change(feedback.thumbsDown);
		
		// save timestamp of first load to trigger
		if(window.localStorage.getItem("feedback_access") === null) {
			window.localStorage.setItem('feedback_access', JSON.stringify(moment()));
		} else {
			var first_access = JSON.parse(window.localStorage.getItem("feedback_access"));
			if(moment(first_access).add(feedback.showFeedbackInterval,"days").isBefore(moment())) {
				$.mobile.changePage('#feedback');
			}
		}
	},
	setData: function(data) {
		var username = window.localStorage.getItem("username");
		var sessionId = window.localStorage.getItem("sessionId");
		var timestamp = new Date().getTime();
		var hash = CryptoJS.MD5(username+timestamp+device.uuid+sessionId)+"";
		hash = hash.toUpperCase();

		$.ajax({
			type: "POST",
			crossDomain: true,
			contentType: "application/json; charset=utf-8",
			url: app.mobileBaseUrl+app.feedbackUrl+username+"/"+timestamp+"/"+device.uuid+"/"+hash,
			data: JSON.stringify(data),
			dataType: "json",
			timeout: app.timeout,
			success: function(json) {
				if(json.status == 'success') {
					$('#feedbackText').val('');
					logger.info("FEEDBACK: SUCCESS");		
				} else {
					//alert(json.message);
					logger.error("FEEDBACK: ERROR: "+json.message);
					// clear data
					window.localStorage.clear(); 
					// goto login
					authenticate.checkLogin();
				}
			},
			error: function(e) {
				$.mobile.loading('hide');
				logger.error("FEEDBACK: ERROR: "+JSON.stringify(e));
			}
		});
	},
	display: function() {
		if(device.platform == "iOS") {
			// https://itunes.apple.com/au/app/mune/id924368406?mt=8
			$("#feedback-rate").html("<a href=\"#\" onclick=\"window.open('itms-apps://itunes.apple.com/au/app/id924368406');\" data-role=\"button\" class=\"fastclick\">Rate</a>");

		} else if(device.platform == "Android") {
			// https://play.google.com/store/apps/details?id=au.edu.une.mobile
			try {
				$("#feedback-rate").html("<a href='market://details?id=au.edu.une.mobile'); data-role=\"button\" class=\"fastclick\">Rate</a>");
            } catch (ActivityNotFoundException) {
                $("#feedback-rate").html("<a href=\"#\" onclick=\"window.open('https://play.google.com/store/apps/details?id=au.edu.une.mobile','_system', 'location=yes');\" data-role=\"button\" class=\"fastclick\">Rate</a>");
			}
		}
	},
	saveFeedback: function() {
		// get feedback data
		//feedback = {feedback:$('#feedbackText').val(), mood:$("#thumb-buttons :radio:checked").val()};
		var data = {feedback:$('#feedbackText').val(), mood:$("#thumb-buttons :radio:checked").val()};
		if(data.feedback != '') {
			feedback.setData(data);
			feedback.delayNextFeedback(feedback.nextFeedbackInterval, feedback.nextFeedbackIntervalUnit);
			analytics.sendEvent("Feedback","Save Feedback");
			history.back();
		}
	},
	dismissLaterFeedback: function() {
		feedback.delayNextFeedback(feedback.showFeedbackInterval, feedback.showFeedbackIntervalUnit);
		history.back();
	},	
	dismissNeverFeedback: function() {
		feedback.delayNextFeedback(feedback.neverFeedbackInterval, feedback.neverFeedbackIntervalUnit);
		history.back();
	},	
	thumbsUp: function() {
		// show rating links
		var data = {feedback:$('#feedbackText').val(), mood:this.value};
		feedback.setData(data);
		feedback.delayNextFeedback(feedback.nextFeedbackInterval, feedback.nextFeedbackIntervalUnit);
		
		// show rate link
		$("#feedback-rate").show();
		$("#feedback-more").hide();
		
		analytics.sendEvent("Feedback","Thumbs Up");
	},
	thumbsDown: function() {
		// ask question for more feedback
		var data = {feedback:$('#feedbackText').val(), mood:this.value};
		feedback.setData(data);
		feedback.delayNextFeedback(feedback.nextFeedbackInterval, feedback.nextFeedbackIntervalUnit);
		
		// hide rate link
		$("#feedback-rate").hide();
		$("#feedback-more").show();
		
		analytics.sendEvent("Feedback","Thumbs Down");
	},
	delayNextFeedback: function(amount, unit) {
		var first_access = JSON.parse(window.localStorage.getItem("feedback_first_access"));
		first_access = moment(first_access).add(amount,unit)
		window.localStorage.setItem('feedback_access', JSON.stringify(first_access));
	}
};
