var gradeCalculator = {
    disclaimerVersion: "1", // change this to force redisplay of disclaimer if change disclaimer text content
    disclaimerUrl: "#calculator-disclaimer",

    gradeScheme: { "0": "Fail", "50": "Pass", "65": "Credit", "75": "Distinction", "85": "High Distinction" },

    initialize: function () {
        this.bindEvents();
    },
    bindEvents: function () {
        document.addEventListener('deviceready', this.deviceReady, false);
    },
    deviceReady: function () {
        var _this = gradeCalculator;

        // click on 'ok' button in disclaimer sets 'seen' flag and closes popup
        $("#calculator-disclaimer-seen").click(function () {
            _this.setSeen();
            $(_this.disclaimerUrl).popup("close");
        });
    },
    getData: function () {

    },

    isSeen: function () {
        return (window.localStorage.getItem(this.disclaimerUrl + this.disclaimerVersion) !== null);
    },

    setSeen: function () {
        window.localStorage.setItem(this.disclaimerUrl + this.disclaimerVersion, "seen");
    },

    display: function (unitCode) {
        if (!this.isSeen()) {
            // timeout so page has time to fully initialize. Without timeout the popup never displays
            var _this = this;
            setTimeout(function () {
                $(_this.disclaimerUrl).popup();
                $(_this.disclaimerUrl).popup("open");
            }, 500);
        }

        if (!(window.localStorage.getItem('unit_' + unitCode) === null)) {
            var html = "<form>";
            html += "<h2>In " + unitCode + ", I want to get a</h2><select name=\"desiredgrade\" id=\"desiredgrade\">";
            for (var grade in this.gradeScheme) {
                if (grade != 0) {
                    html += "<option value=\"" + grade + "\">" + this.gradeScheme[grade] + "</option>";
                }
            }
            html += "</select>";
            html += "<table>";
            html += "<tr><td>Title</td><td>Weight</td><td>Achieved Grade (%)</td><td>Minimum Required Grade (%)</td></tr>";
            var unitInfo = JSON.parse(window.localStorage.getItem('unit_' + unitCode));
            for (var assessment in unitInfo.assessments) {
                html += "<tr><td>" + unitInfo.assessments[assessment].title + "</td>";
                html += "<td>" + unitInfo.assessments[assessment].weight + "%</td>";
                html += "<td><input type=\"number\" class=\"assessmentinput\" type=\"text\" name=\"assessment_" + assessment + "\" id=\"assessment_" + assessment + "\"/></td>";
                html += "<td><div class=\"requiredgrade\" id=\"required_" + assessment + "\"></div></td></tr>";
            }
            html += "</table>";
            html += "<div id=\"totalgrade\"></div>";
            html += "<input type= \"hidden\" name=\"unitCode\" id=\"unitCode\" value=\"" + unitCode + "\"/>";
            html += "</form>";

            $("#gradecalculatorform").html(html);
            $("#gradecalculatorform").trigger("create");

            $("input.assessmentinput").keyup(this.calculateGrades);
            $("#desiredgrade").change(this.calculateGrades);
        }

        // set form data to saved values
        if (!(window.localStorage.getItem('gradecalc_' + unitCode) === null)) {

            var gradecalc = JSON.parse(window.localStorage.getItem('gradecalc_' + unitCode));
            $("#desiredgrade").val(gradecalc.desiredGrade);
            $('#desiredgrade').selectmenu("refresh", true);
            for (var assessment in gradecalc.assessments) {
                $("#assessment_" + assessment).val(gradecalc.assessments[assessment].grade);
            }
        }

        this.calculateGrades();
    },
    // calculate the grades in the current grade calulator form
    calculateGrades: function () {
        var gradecalc = new Object();
        gradecalc.unitCode = $("#unitCode").val();
        gradecalc.desiredGrade = $("#desiredgrade").val();
        gradecalc.totalGrade = 0;
        gradecalc.requiredGrade = 0;
        gradecalc.completedPercent = 0;
        gradecalc.remainingPercent = 0;
        gradecalc.assessments = new Array();

        if (gradecalc.desiredGrade) {
            var unitInfo = JSON.parse(window.localStorage.getItem('unit_' + gradecalc.unitCode));
            for (var assessment in unitInfo.assessments) {
                var calcAssessment = new Object();
                calcAssessment.grade = $("#assessment_" + assessment).val();
                calcAssessment.weight = unitInfo.assessments[assessment].weight;

                if (calcAssessment.grade) {
                    gradecalc.completedPercent += calcAssessment.weight;
                    gradecalc.totalGrade += calcAssessment.grade * calcAssessment.weight / 100;
                } else {
                    gradecalc.remainingPercent += calcAssessment.weight;
                }
                gradecalc.assessments.push(calcAssessment);
            }
            gradecalc.requiredGrade = (gradecalc.desiredGrade - gradecalc.totalGrade) / gradecalc.remainingPercent * 100;

            // write required grade to each non attempted assignment
            var completecount = 0;
            for (var assessment in gradecalc.assessments) {
                if (!gradecalc.assessments[assessment].grade) {
                    if (gradecalc.requiredGrade < 0) {
                        $("#required_" + assessment).html(0);
                    } else if (gradecalc.requiredGrade > 100) {
                        $("#required_" + assessment).html("<span class=\"red\">" + gradecalc.requiredGrade.toFixed(1) + "</span>");
                    } else {
                        $("#required_" + assessment).html(gradecalc.requiredGrade.toFixed(1));
                    }
                } else {
                    completecount++;
                    $("#required_" + assessment).html("");
                }
            }

            // if all assessments complete, then display the calculated final grade
            $("#totalgrade").html("");
            if (completecount == gradecalc.assessments.length) {
                for (var grade in gradeCalculator.gradeScheme) {
                    if (gradecalc.totalGrade >= grade) {
                        $("#totalgrade").html("<h2>Your final grade is a " + gradeCalculator.gradeScheme[grade] + "</h2>");
                    }
                }
            }
        }

        // store gradecalc data
        window.localStorage.setItem('gradecalc_' + gradecalc.unitCode, JSON.stringify(gradecalc));
    },
};