/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
	mobileBaseUrl:        'https://my.une.edu.au/mobile/',
    casUrl:    	  	      "https://login.une.edu.au",
	mapUrl:    	  	      'https://my.une.edu.au/map/',
	rssFeedUrl: 	      "https://blog.une.edu.au/studentexperience/feed/",
	enrolledUnitsUrl:     "enrolled-units/",
	resultsUrl:     	  "results/",
	feedbackUrl:     	  "feedback/",
	loginUrl:             "login/",
	logoutUrl:            "logout/",
	timeout:              10 * 1000, /* AJAX timeout milliseconds */
	cacheTimeoutUnit:     'hours',
	cacheSettings: {
						  "enrolledUnits": {timeout:6}, 
						  "unitinfo":      {timeout:24}, 
						  "timetable":     {timeout:24}, 
						  "map":           {timeout:24}, 
						  "results":       {timeout:4}, 
						  "rssfeed":       {timeout:6}
	},
	loglevel: 			  'ERROR',
	
    // Application Constructor
    initialize: function() {
		// init fastclick
		var button = document.querySelector(".fastclick");
		new FastClick(button);
		this.bindEvents();

		analytics.initialize();

		// push.initialize();   // TODO: initialize when rewrite push to work with new push plugin

		whatsnew.initialize();
		authenticate.initialize();
		enrolment.initialize();
		unitinfo.initialize();
		timetable.initialize();
		map.initialize();
		gradeCalculator.initialize();
		results.initialize();
		rssfeed.initialize();
		feedback.initialize();

    },
    // Bind Event Listeners
    bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
    },
    // deviceready Event Handler
    deviceReady: function() {
		$("#cleardatabutton").click(app.clearData);
		$("#refreshdata").click(app.refreshData);
		// update copyright year to current year
		$(".copyright-year").html(moment().format("YYYY"));
    },
	clearData: function() {
		navigator.notification.confirm(
			'Are you sure you want to clear all app data?',
			function(buttonIndex) {
				if(buttonIndex == 1) {
					window.localStorage.clear();
					authenticate.checkLogin();
				}
			},            			
			'Clear Data',           
			['Yes','No']  
		);
	},
	refreshData: function() {
		$.mobile.loading('show');
		enrolment.getData();
		rssfeed.getData();
		map.getData();
		push.register();
	},
};
