"use strict";
var map = {
	map: 					null,
	defaultLatitude: 		151.6432973742485,
	defaultLongitude: 		-30.48727661602331,
	defaultZoom: 			17,
	mapDiv: 				"map_canvas",
	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
	    logger.info("MAP: initialize");

		// search for locations, backspace NOT captured >: grrrr
		$(document).on('keyup', '#map_search_query', function() { map.search(); });
		$(document).on('focus', '#map_search_query', function() { map.search(); });
		// clear search when clear button pressed
		$(document).on('click', '.ui-input-clear', function(e){ $("#map_locations").hide();	});

		$(window).on("orientationchange", function(event) { map.orientationchange(); });
		
		// re-render the map while it is visible to correctly calculate its dimensions
		$(document).on( "pagecontainershow", function( event, ui ) {
			var pageId = $('body').pagecontainer('getActivePage').prop('id');
			if(pageId == "map") {
				map.orientationchange();
			}
		});

		$("#"+map.mapDiv).css("width", window.innerWidth);
		$("#"+map.mapDiv).css("height", map.getRealContentHeight());	
		
		var mapOptions = {
		    'backgroundColor': 'white',
		    'controls': {
		        'compass': true,
		        'myLocationButton': true,
		        'indoorPicker': true,
		        'zoom': true
		    },
		    'gestures': {
		        'scroll': true,
		        'tilt': true,
		        'rotate': true,
		        'zoom': true
		    },
		    'camera': {
		        'latLng': new plugin.google.maps.LatLng(map.defaultLongitude, map.defaultLatitude),
		        'zoom': map.defaultZoom
		    }
		};
		
		// Hide statusbar so map renders correctly
		StatusBar.hide();
		
		// Initialize the map view
		map.map = plugin.google.maps.Map.getMap(document.getElementById(map.mapDiv),mapOptions);

		// Show status bar again
		StatusBar.show();
		
		map.map.addEventListener(plugin.google.maps.event.MAP_READY, function onMapReady() {
	        logger.info("MAP: ready");
		    map.display();
		    map.getData();
		});

	},

	getData: function() {
	    logger.info("MAP: getData");
		var cacheInfo = cache.getCacheInfo("map");
		if(cacheInfo.expired) {
			$.ajax({
				type: "GET",
				crossDomain: true,
				contentType: "application/json; charset=utf-8",
				url: app.mapUrl+"buildings.json",
				dataType: "json",
				timeout: app.timeout,
				success: function(json) {
					cache.setCacheData(cacheInfo, "mapData", json);
					map.display();
					logger.info("MAP: getData SUCCESS");
				},
				error: function(e) {
				    logger.error("MAP: getData ERROR: " + JSON.stringify(e));
				}
			});
		}
	},
	display: function() {
	    logger.info("MAP: display");
		// render side menu
		var mapData = cache.getCacheData("mapData");
		if(mapData) {
	        logger.info("MAP: display mapData");
			var locationHtml = "<ul id=\"map_locations_list\" data-role=\"listview\">";
			for (var b in mapData) {
				locationHtml += "<li><a href=\"#map\" id=\""+mapData[b].code+"\" class=\"location-menu-item\" onclick=\"map.placeMarker('"+mapData[b].code+"',true); \">"+mapData[b].code+" "+mapData[b].name+"</a></li>";
			}
			locationHtml += "</ul>";
			$("#map_locations").html(locationHtml);
			$("#map_locations_list").init();
		}
	},
	placeMarker: function(code, centreMap) {
	    logger.info("MAP: placeMarker");
		var mapData = cache.getCacheData("mapData");
		if(!(mapData === null)) {
			// clear all markers
			map.map.clear();
			// add a 0 to code so C34 becomes C034 and C4 becomes C004
			code = ( mapData[code] ? code : [code.slice(0, 1), '0', code.slice(1)].join('') );
			code = ( mapData[code] ? code : [code.slice(0, 1), '0', code.slice(1)].join('') );
			if(mapData[code]) {
				var position = new plugin.google.maps.LatLng(mapData[code].latitude,mapData[code].longitude)
				map.map.addMarker({
					'position': position,
					'title': mapData[code].code+" - "+mapData[code].name
				}, function(marker) {
					marker.showInfoWindow();
				});
				if(centreMap) {			 
					map.map.moveCamera({
					  'target': position,
					  'zoom': map.defaultZoom
					});
				}
			} 
		}
	},
	search: function() {
		var query = $.trim($("#map_search_query").val());
		
		if(query == '') { 
			$("#map_locations").hide(); 
		} else { 
			$("#map_locations").show(); 
		}
		var mapData = cache.getCacheData("mapData");
		if(mapData) {
			// add '0' padding to help the search find c34
			var queryItems = query.split(' ');
			var newQuery = [];
			for (var q in queryItems) {
				var text = queryItems[q];
				newQuery.push(text);
				text = (mapData[text] ? text : [text.slice(0, 1), '0', text.slice(1)].join(''));	
				newQuery.push(text);
				text = (mapData[text] ? text : [text.slice(0, 1), '0', text.slice(1)].join(''));	
				newQuery.push(text);
			}
			
			query = newQuery.join('|');
			$(".location-menu-item").each(function() {
				($(this).text().search(new RegExp(query, "i")) < 0) ? $(this).hide().removeClass('visible') : $(this).show().addClass('visible');
			});	
		}
	},
	orientationchange: function() {
		$("#"+map.mapDiv).css("width", window.innerWidth);
		$("#"+map.mapDiv).css("height", map.getRealContentHeight());	
		map.map.refreshLayout();
	},
	getRealContentHeight: function() {
	    logger.info("MAP: getRealContentHeight");
		var header = $.mobile.activePage.find("div[data-role='header']:visible");
		var footer = $.mobile.activePage.find("div[data-role='footer']:visible");
		var content = $.mobile.activePage.find("div[data-role='content']:visible:visible");
		var viewport_height = $(window).height();
		
		var content_height = viewport_height - header.outerHeight() - footer.outerHeight();
		if((content.outerHeight() - header.outerHeight() - footer.outerHeight()) <= viewport_height) {
			content_height -= (content.outerHeight() - content.height());
		} 
		return content_height+3;
	}
};