var push = {
	pushNotification: null,
	defaultSettings: {enabled:false}, // TODO: enable when rewrite to work with new plugin
	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
		push.register();
		push.display();
		$("#toggle-notifications").change(push.toggleNotifications);
	},
	display: function() {
		var settings = push.getSettings();
		var checked = settings.enabled ? "checked=''" : "";
		var html = "<form>";
		html += "<div class='ui-field-contain'>";
		html += "<label for='toggle-notifications'>Enable Notifications</label>";
		html += "<input type='checkbox' data-role='flipswitch' name='toggle-notifications' id='toggle-notifications' class='custom-size-flipswitch' "+checked+">";
		html += "</div>";
		html += "</form>";
		$("#notification-settings").html(html);
	},
	toggleNotifications: function() {
		var settings = push.getSettings();
		settings.enabled = $("#toggle-notifications").is(':checked');
		push.setSettings(settings);
		
		if(settings.enabled) {
			push.register();
			analytics.sendEvent("Notifications","Enable");
		} else {
			push.unregister();
			analytics.sendEvent("Notifications","Disable");
		}
	},
	register: function() {
		if(authenticate.isLoggedIn && push.getSettings().enabled) {
			analytics.sendEvent("Notifications","Enabled");
			push.pushNotification = window.plugins.pushNotification;
			
			if(device.platform == 'android' || device.platform == 'Android' || device.platform == "amazon-fireos"){
				push.pushNotification.register(
					push.successHandler,
					push.errorHandler,
					{
						"senderID":"521905626871",
						"ecb":"push_onNotification"
				});
				logger.info("PUSH: REGISTER: android");
			} else {
				push.pushNotification.register(
					push.tokenHandler,
					push.errorHandler,
					{
						"badge":"true",
						"sound":"true",
						"alert":"true",
						"ecb":"push_onNotificationAPN"
				});
				logger.info("PUSH: REGISTER: ios");
			}
		} else {
			analytics.sendEvent("Notifications","Disabled");
		}
	},
	unregister: function() {
		if(push.pushNotification) {
			if(device.platform == 'android' || device.platform == 'Android' || device.platform == "amazon-fireos") {
				push.pushNotification.unregister(
					push.successHandler, 
					push.errorHandler, 
					{
						"senderID":"521905626871"
					});	
					logger.info("PUSH: UNREGISTER: android");
			} else {
				push.pushNotification.unregister(
					push.successHandler, 
					push.errorHandler, 
					{
						"badge":"true",
						"sound":"true",
						"alert":"true"
				});	
				logger.info("PUSH: UNREGISTER: ios");
			}
		}
		window.localStorage.removeItem("pushDeviceToken");
	},
	successHandler: function(result) {
		logger.info("PUSH: SUCCESS: "+result);
	},
	errorHandler: function(error) {
		logger.error("PUSH: ERROR: "+error);
	},
	tokenHandler: function(result) {
		push.sendDeviceToken("ios", result);
	},
	sendDeviceToken: function(deviceType, deviceToken) {
		if(window.localStorage.getItem("pushDeviceToken") === null) {
			var data = {device: deviceType, devicetoken:deviceToken};
			var username = window.localStorage.getItem("username");
			var sessionId = window.localStorage.getItem("sessionId");
			var timestamp = new Date().getTime();
			var hash = CryptoJS.MD5(username+timestamp+device.uuid+sessionId)+"";
			hash = hash.toUpperCase();
			$.ajax({
				type: "POST",
				crossDomain: true,
				url: app.mobileBaseUrl+'push/register/'+username+"/"+timestamp+"/"+device.uuid+"/"+hash,
				data: data,
				timeout: app.timeout,
				success: function(json) {
					if(typeof json.pushDeviceToken != 'undefined') {
						window.localStorage.setItem("pushDeviceToken", json.pushDeviceToken);
						logger.info("PUSH: REGISTERED: "+deviceType+": devicetoken = " + deviceToken);
					}
				},
				error: function(e) {
					logger.error("PUSH: ERROR: sendDeviceToken: "+JSON.stringify(e));
				}
			});
		}
	},
	processNotification: function(payload) {
		logger.debug("PUSH: payload: "+JSON.stringify(payload));
		switch(payload.target) {
			case 'results':
				results.push(payload);
				break;
		}	
	},
	getSettings: function() {
		if(window.localStorage.getItem("notification_settings") === null) {
			return push.defaultSettings;
		} else {
			return JSON.parse(window.localStorage.getItem("notification_settings"));
		}
	},
	setSettings: function(settings) {
		window.localStorage.setItem("notification_settings", JSON.stringify(settings));
	}
};

function push_onNotification(e) {
	logger.debug("PUSH: message: "+JSON.stringify(e.event));
	switch(e.event) {
		case 'registered':
			if(e.regid.length > 0) {
				push.sendDeviceToken("android", e.regid);
			}
			break;

		case 'message':
			logger.debug("PUSH: e: "+ JSON.stringify(e));
			// if this flag is set, this notification happened while we were in the foreground.
			// you might want to play a sound to get the user's attention, throw up a dialog, etc.
			if(e.foreground) {
				logger.info("PUSH: INLINE NOTIFICATION");
			} else {  // otherwise we were launched because the user touched a notification in the notification tray.
				if(e.coldstart) {
					logger.info("PUSH: COLDSTART NOTIFICATION");
				} else {
					logger.info("PUSH: BACKGROUND NOTIFICATION");
				}
			}
			logger.debug("PUSH: message: "+ JSON.stringify(e.payload));
			push.processNotification(e.payload);
			break;

		case 'error':
			logger.error("PUSH: ERROR: "+ e.msg);
			break;

		default:
			logger.error("PUSH: ERROR: Unknown, an event was received and we do not know what it is");
			break;
	}
}

function push_onNotificationAPN(event) {
	logger.debug("PUSH: message: "+JSON.stringify(event));
	var payload = JSON.parse(event.data);

	if(event.alert) {
	//	navigator.notification.alert(event.alert);
	}
	
	if(payload) {
		push.processNotification(payload);
	}

	//if(event.sound) {
	//	var snd = new Media(event.sound);
	//	snd.play();
	//}

	if(event.badge) {
		push.pushNotification.setApplicationIconBadgeNumber(push.successHandler, push.errorHandler, event.badge);
	}
}