var results = {
	
	graph: null,
	course: "",
	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
		$('#results').bind('pageinit', this.pageInit);
		$('#results').bind('pageshow', this.displayGraph);
		$(window).on("orientationchange", this.displayGraph);
	},
	pageInit: function() {
		results.display();
	},
	deviceReady: function() {
		
	},
	getData: function() {
		var cacheInfo = cache.getCacheInfo("results");
		if(cacheInfo.expired) {
			var username = window.localStorage.getItem("username");
				var sessionId = window.localStorage.getItem("sessionId");
				var timestamp = new Date().getTime();
				var hash = CryptoJS.MD5(username+timestamp+device.uuid+sessionId)+"";
				hash = hash.toUpperCase();
				$.ajax({
					type: "GET",
					crossDomain: true,
					contentType: "application/json; charset=utf-8",
					url: app.mobileBaseUrl+app.resultsUrl+username+"/"+timestamp+"/"+device.uuid+"/"+hash,
					dataType: "json",
					timeout: app.timeout,
					success: function(json) {
						//logger.debug(JSON.stringify(json.results));
						if(json.status == 'success') {
							cache.setCacheData(cacheInfo, "resultsData", json);
							results.display();
							logger.info("RESULTS: SUCCESS");		
						} else {
							alert(json.message);
							logger.error("RESULTS: ERROR: "+json.message);
							// clear data
							window.localStorage.clear(); 
							// goto login
							authenticate.checkLogin();
						}
					},
					error: function(e) {
						$.mobile.loading('hide');
						logger.error("RESULTS: ERROR: "+JSON.stringify(e));
					}
				});
		}
	},
	display: function() {
		var resultsData = cache.getCacheData("resultsData");
		if(!(resultsData === null)) {
			var html = "";
			
			for(var c in resultsData.results) {
				html += "<div id=\"collapsible_"+c+"\" data-role=\"collapsible\"><h3>"+c+"</h3>";
				html += "<div class=\"results-gpa\">Grade Point Average: "+parseFloat(resultsData.gpa[c]).toFixed(2)+"</div>";
				html += "<div id=\"resultsList_"+c+"\" data-role=\"collapsibleset\" data-content-theme=\"a\" data-iconpos=\"right\">";
				for(var tp in resultsData.results[c]) {				
					html += "<div data-role=\"collapsible\"><h3>"+tp+"</h3>";
					for(var r in resultsData.results[c][tp]) {
						var result = resultsData.results[c][tp][r];
						if (result.mark == null)
							result.mark = "";
						html += "<span class='grade-unitcode'>"+result.unitCode+"</span><span class='grade-mark'>"+result.mark+"</span><span class='grade-grade'>"+result.grade+"</span><span class='grade-gradename'>"+result.gradeName+"</span><br />";
					}
					html += "</div>";
				}
				html += "</div>";
				html += "</div>";
			}
			
			$("#courseList").html(html);
			$("#courseList").collapsibleset().collapsibleset("refresh");
			
			
			for(var c in resultsData.results) {
				$("#resultsList_"+c).collapsibleset().collapsibleset("refresh");
				$("#resultsList_"+c).children(":last").collapsible("expand");
				$("#collapsible_"+c).on( "collapsibleexpand", function( event, ui ) {
					var id = $(this).attr('id').split("_")[1];
					results.course = id;
					results.displayGraph();
				});
			}
			$("#courseList").children(":first").collapsible("expand");
		}
	},
	displayGraph: function() {
		if($.mobile.activePage.attr("id") == "results") {
			$("#resultsGraph").css("width", $("resultsGraph-container").innerWidth);
			var resultsData = cache.getCacheData("resultsData");
			if(!(resultsData === null)) {
				var courseResultsData = resultsData.results[results.course];
				var gpaData = [];
				var courseGpaData = [];
				var xticks = [];
				var courseGpa = 0;
				var courseGpaCount = 0;
				var i = 0;
				
				// build graph of gpa data per teaching period and total gpa
				for(var tp in courseResultsData) {
					var resultList = courseResultsData[tp];
					xticks.push([i,tp.replace(" ","<br/>")]);
					
					// calculate gpa for each tp
					var gpa = 0;
					var gpaCount = 0;
					for(var j in resultList) {
						if(resultList[j].gpaValue != null) {
							gpa += resultList[j].gpaValue * resultList[j].creditPoints;
							courseGpa += resultList[j].gpaValue * resultList[j].creditPoints;
							gpaCount += resultList[j].creditPoints;
							courseGpaCount += resultList[j].creditPoints;
						}
					}
					gpaData.push([i, gpa/gpaCount]);
					courseGpaData.push([i, courseGpa/courseGpaCount]);
					i++;
				}
				
				// build y axis
				var yticks = [[3,""],[4,"P"],[5,"C"],[6,"D"],[7,"HD"]];
				
				if(results.graph != null) results.graph.destroy();
				
				results.graph = $.plot("#resultsGraph", 
									   [{label: "course gpa", points: {show: (i==1)}, lines: {show: true}, data:courseGpaData}, {label:"period gpa", points: {show: (i==1)}, lines: {show: true}, data:gpaData}],
									   {xaxis: {ticks:xticks, color:"#aaa",font:{color: "#ccc"}},
										yaxis: {ticks:yticks, color:"#aaa",font:{color: "#ccc"}},
										grid: {backgroundColor:{colors:["#333", "#999"], color:"#aaa"}}
									   }
				);
			}
			logger.info("RESULTS: displayGraph "+results.course);
		}
	},
	push: function(data) {
		cache.clearCacheInfo("results");
		results.getData();
	}
};