var timetable = {
	timetableDateFormat:  'ddd, DD MMM YYYY HH:mm:ss',
	currentDay: 	      moment(),
	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
		$("#timetableday").click(function()   {timetable.setView('day');  timetable.display(timetable.getToday());});
		$("#timetableweek").click(function()  {timetable.setView('week'); timetable.display(timetable.getToday());});	
		$("#timetableall").click(function()   {timetable.setView('all');  timetable.display(timetable.getToday());});
		$("#timetableprev").click(function()  {timetable.display(timetable.getPrev());});
		$("#timetablenext").click(function()  {timetable.display(timetable.getNext());});	
		$("#timetabletoday").click(function() {timetable.display(timetable.getToday());});
		timetable.display(timetable.getToday());
	},
	getData: function() {
		if(authenticate.isLoggedIn) { // TODO and if have data connection
			var cacheInfo = cache.getCacheInfo("timetable");
			if(cacheInfo.expired) {
				var deferreds = [];
				var enrolledUnits = JSON.parse(window.localStorage.getItem("enrolledUnits"));		
				for(var e in enrolledUnits) {
					if(enrolledUnits[e].timetableUrl) {
						logger.info("TIMETABLE: "+enrolledUnits[e].timetableUrl+".json");
						var deferred = $.Deferred();
						$.ajax({
							type: "GET",
							crossDomain: true,
							url: enrolledUnits[e].timetableUrl+".json",
							dataType: "json",
							timeout: app.timeout,
						}).complete(deferred.resolve);
						deferreds.push(deferred);
					}					
				}

				$.when.apply($, deferreds).done(function () {
					// process and combine the timetables into one map
					var allTimetables = {};
					for(var tt in arguments) {	
						if(arguments[tt][1] == "success") {
							var json = arguments[tt][0].responseJSON;
							// translate data into hash[day] : [event,event,event ...]
							for(event in json) {
								var startDateStr = moment(json[event].start, timetable.timetableDateFormat).format('YYYY-MM-DD');
								if(allTimetables[startDateStr] == null) {
									allTimetables[startDateStr] = [];
								}
								allTimetables[startDateStr].push(json[event]);
							}
						} else {
							logger.error("TIMETABLE: ERROR: "+ arguments[tt][1]);
						}
					}
					
					// sort each day by start date
					for(var day in allTimetables) {
						allTimetables[day].sort(timetable.compareEvents);
					}
										
					// store combined timetable
					cache.setCacheData(cacheInfo, "timetable", allTimetables);
										
					timetable.display(timetable.getToday());
				});
			}
		}	
	},
	display: function(day) {
		var timetableData = cache.getCacheData("timetable");
		if(!(timetableData === null)) {
			var eventsHtml = "";
		
			if(timetable.getView() == 'day') {
				// enable prev and next buttons
				$('#timetableprev').removeClass("ui-disabled");
				$('#timetablenext').removeClass("ui-disabled");
				$('#timetableday').addClass("ui-btn-active");
				$('#timetableweek').removeClass("ui-btn-active");
				$('#timetableall').removeClass("ui-btn-active");
				
				var events = null;
				// get days worth of events
				events = timetableData[day.format('YYYY-MM-DD')];
				$("#date").html(day.format('dddd Do [of] MMMM YYYY'));
				
				eventsHtml += "<div class='day'>";
				if(events != null) {
					for(var event in events) {
						eventsHtml += timetable.displayEvent(events[event]);
					}	
				} else {
					eventsHtml += "<div class='date'>No events</div>";									
				}
				eventsHtml += "</div>";
			} else if(timetable.getView() == 'week') {
				// enable prev and next buttons
				$('#timetableprev').removeClass("ui-disabled");
				$('#timetablenext').removeClass("ui-disabled");
				$('#timetableday').removeClass("ui-btn-active");
				$('#timetableweek').addClass("ui-btn-active");
				$('#timetableall').removeClass("ui-btn-active");
				
				// get weeks worth of events
				$("#date").html("Week starting " + day.format('ddd Do [of] MMMM YYYY'));
				
				var events = [];
				var weekDay = moment(day);
				for(var i = 0; i < 6; i++) {
					eventsHtml += "<div class='day'>";
					var weekDayStr = weekDay.format('YYYY-MM-DD');
					events = timetableData[weekDayStr];
					if(events && events.length != 0) {
						var currentDate = moment(weekDay, 'YYYY-MM-DD');
						eventsHtml += "<div class='date'>"+currentDate.format('dddd Do [of] MMMM YYYY')+"</div>";
					}
					for(var event in events) {
						eventsHtml += timetable.displayEvent(events[event]);
					}
					eventsHtml += "</div>";
					weekDay.add("day", 1);
				}
			} else if(timetable.getView() == 'all') {
				// disable prev and next buttons
				$('#timetableprev').addClass("ui-disabled");
				$('#timetablenext').addClass("ui-disabled");
				$('#timetableday').removeClass("ui-btn-active");
				$('#timetableweek').removeClass("ui-btn-active");
				$('#timetableall').addClass("ui-btn-active");
				
				// get all events
				var events = [];
				for(dayData in timetableData) {
					eventsHtml += "<div class='day'>";
					events = timetableData[dayData];
					if(events && events.length != 0) {
						var currentDate = moment(dayData, 'YYYY-MM-DD');
						eventsHtml += "<div class='date'>"+currentDate.format('dddd Do [of] MMMM YYYY')+"</div>";
					}
					for(var event in events) {
						eventsHtml += timetable.displayEvent(events[event]);
					}
					eventsHtml += "</div>";
				}
				$("#date").html("All events");
			}
			$("#timetablecolumn").html(eventsHtml);
			
			// set current day
			this.currentDay = day;
		}
	},
	displayEvent: function(event) {
		var eventsHtml = "";
		var startDate = moment(event.start, timetable.timetableDateFormat);
		var endDate = moment(event.end, timetable.timetableDateFormat);
		eventsHtml += "<div class=\"event\">";
		eventsHtml += "  <div class=\"time\">" + startDate.format('h:mm a') + " - " + endDate.format('h:mm a') + "</div>";
		eventsHtml += "  <div class=\"title\">" + event.type + " - " + event.code + "</div>";
		eventsHtml += "  <div class=\"location\"><a href=\"#map\" onclick=\"map.placeMarker('"+event.building+"', true)\" class=\"fastclick\">" + event.location+" ("+event.building+")</a></div>";
		eventsHtml += "</div>";
		return eventsHtml;
	},
	getNext: function() {
		if(timetable.getView() == 'day') {
			return timetable.currentDay.add('days', 1);
		} else if(timetable.getView() == 'week') {
			return timetable.currentDay.add('week', 1);
		}
	},
	getPrev: function() {
		if(timetable.getView() == 'day') {
			return timetable.currentDay.subtract('days', 1);
		} else if(timetable.getView() == 'week') {
			return timetable.currentDay.subtract('week', 1);
		}	
	},
	getToday: function() {
		if(timetable.getView() == 'day') {
			return moment();
		} else if(timetable.getView() == 'week') {
			return moment().day(0);
		}	
	},
	setView: function(view) {
		window.localStorage.setItem("timetable_view", view);
	},
	getView: function(view) {
		if(window.localStorage.getItem("timetable_view") === null) {
			return 'week';
		} else {
			return window.localStorage.getItem("timetable_view");
		}
	},
	compareEvents: function(a,b) {
		var aStart = moment(a.start, app.timetableDateFormat);
		var bStart = moment(b.start, app.timetableDateFormat);
	
		if (aStart.isBefore(bStart))
			return -1;
		if (aStart.isAfter(bStart))
			return 1;
		return 0;
		
	},
};