var unitinfo = {
	
	initialize: function() {
		this.bindEvents();
	},
	bindEvents: function() {
        document.addEventListener('deviceready', this.deviceReady, false);
	},
	deviceReady: function() {
		
	},
	getData: function() {
		if(authenticate.isLoggedIn) { // and if have data connection
			var cacheInfo = cache.getCacheInfo("unitinfo");
			if(cacheInfo.expired) {
				var deferreds = [];
				var enrolledUnits = JSON.parse(window.localStorage.getItem("enrolledUnits"));		
				for(var e in enrolledUnits) {
					if(enrolledUnits[e].caucUrl) {
						var deferred = $.Deferred();
						$.ajax({
							type: "GET",
							crossDomain: true,
							//contentType: "text/html; charset=utf-8",
							url: enrolledUnits[e].caucUrl+".json",
							dataType: "json",
							timeout: app.timeout,
						}).complete(deferred.resolve);
						
						deferreds.push(deferred);
					}					
				}

				$.when.apply($, deferreds).done(function () {
					// process and store unitinfo
					for(var unit in arguments) {
						if(arguments[unit][1] == "success") {
							var json = JSON.parse(arguments[unit][0].responseText);
							//logger.debug(JSON.stringify(json));
							logger.info("UNITINFO: SUCCESS: "+json.code);
							// store combined timetable
							cache.setCacheData(cacheInfo, 'unit_'+json.code, json);
						} else {
							logger.error("UNITINFO: ERROR: "+JSON.stringify(arguments[unit]));
						}
					}
					enrolment.display();
				});		
			}
		}
	},
	display: function(unitCode) {
		var unitInfo = cache.getCacheData('unit_'+unitCode);
		if(!(unitInfo === null)) {
			var html = '';
			$("#unitinfotitle").html(unitInfo.code+" - "+unitInfo.title);
			
			// Description
			html += "<div data-role=\"collapsible\"><h3>Description</h3>";
			html += "<p>"+unitInfo.description+"</p></div>";
			
			// Coordinators
			html += "<div data-role=\"collapsible\"><h3>Coordinators</h3>";
			html += "<ul>";
			for(var coord in unitInfo.coordinators) {
				html += "<li>"+unitInfo.coordinators[coord].description+" - "+unitInfo.coordinators[coord].name+" (<a href='mailto:"+unitInfo.coordinators[coord].email+"'>"+unitInfo.coordinators[coord].email+"</a>)</li>";
			}
			html += "</ul></div>";
			
			// Assessments
			html += "<div data-role=\"collapsible\"><h3>Assessments</h3>";
			html += "<ul>";
			for(var assessment in unitInfo.assessments) {			
				html += "<li><div>"
				+ unitInfo.assessments[assessment].title
				+ (unitInfo.assessments[assessment].formattedExamLength ? ", " + unitInfo.assessments[assessment].formattedExamLength : "")
				+ (unitInfo.assessments[assessment].wordCount ? " (" + unitInfo.assessments[assessment].wordCount+" words)" : "")
				+ "<p>"+unitInfo.assessments[assessment].weight+"% of final grade</p>"
				+ (unitInfo.assessments[assessment].notes ? "<p>Notes: "+unitInfo.assessments[assessment].notes+"</p>" : "")
				+ "</div></li>";
			}
			html += "</ul></div>";
			
			// Materials
			html += "<div data-role=\"collapsible\"><h3>Materials</h3>";
			html += "";
			for(var m in unitInfo.materials) {
				var material = unitInfo.materials[m];
				var hasUsableISBN = material.reference != 'SUP' && material.reference != 'NTR';
				var hasPublicationDetails = material.author || material.publisher || material.edition || material.yearPublished;
				
				html += "<div>"
				+ '<strong>' + material.title + '</strong><br/>'
				+ material.requirementDescription
				+ '<p>'
				+ (hasUsableISBN ? 'ISBN: '+material.reference + (hasPublicationDetails ? '<br/>' : '') : '')
				+ (material.author ? material.author : '')
				+ (material.publisher ? ' ' + material.publisher : '')
				+ (material.edition ? ' ' + material.edition : '')
				+ (material.yearPublished ? ' ' + material.yearPublished : '')
				+ '</p>'
				+ (material.notes ? " Note: "+material.notes : "")
				+ (material.teachingPeriod.description && material.studyMode.description ? '<p>Text refers to:' + material.teachingPeriod.description + ', ' + material.studyMode.description +'</p>': '')
				+ "</div>";
			}
			html += "</div>";
			
			// Exam
			html += "<div data-role=\"collapsible\"><h3>Exam</h3>";
			html += "<p>" + unitInfo.exam + "</p>";
			if(unitInfo.examInstructionsText) {
				html += "<p>"+unitInfo.examInstructionsText+"</p>";
			}
			if(unitInfo.examInstructionsUrl) {
				html += "<p><a href="+unitInfo.examInstructionsUrl+">Further Information</a></p>";
			}
			html += "</div>";
			
			// Intensive School(s)
			if(unitInfo.intensiveSchools.length > 0) {
				html += "<div data-role=\"collapsible\"><h3>Intensive School(s)</h3>";
				for(var is in unitInfo.intensiveSchools) {
					html += unitInfo.intensiveSchools[is].attendance;
					html += (unitInfo.intensiveSchools[is].formattedStart ? " from " + unitInfo.intensiveSchools[is].formattedStart : "");
					html += (unitInfo.intensiveSchools[is].formattedEnd ? " until " + unitInfo.intensiveSchools[is].formattedEnd : "");
					html += (unitInfo.intensiveSchools[is].notes ? " ("+unitInfo.intensiveSchools[is].notes+")" : "");
					html += "<br/>";
				}
				
				html += "</div>";
			}
			
			$("#unitinfocontent").html(html);
			$('#unitinfocontent').find("ul[data-role=listview]").listview().listview("refresh");
			$('#unitinfocontent').find("div[data-role=collapsible]").collapsible();
			
			var button = document.querySelector(".fastclick");
			new FastClick(button);	
		}
	},
};
